Model parameters
======================================================================

.. autoclass:: fwdpy11.ModelParams
    :members:

.. autoclass:: fwdpy11.MutationAndRecombinationRates
    :members:
